@@ -4,7 +4,7 @@
  ** Top contributors (to current version):
  **   Morgan Deters, Tim King
  ** This file is part of the CVC4 project.
- ** Copyright (c) 2009-2018 by the authors listed in the file AUTHORS
+ ** Copyright (c) 2009-2019 by the authors listed in the file AUTHORS
  ** in the top-level source directory) and their institutional affiliations.
  ** All rights reserved.  See the file COPYING in the top-level source
  ** directory for licensing information.\endverbatim
@@ -30,13 +30,13 @@
 #ifdef CVC4_CLN_IMP
 #  include <cvc4/util/integer_cln_imp.h>
 #  if SWIG
-     %include "util/integer_cln_imp.h"
+     %include <cvc4/util/integer_cln_imp.h>
 #  endif /* SWIG */
 #endif /* CVC4_CLN_IMP */
 
 #ifdef CVC4_GMP_IMP
 #  include <cvc4/util/integer_gmp_imp.h>
 #  if SWIG
-     %include "util/integer_gmp_imp.h"
+     %include <cvc4/util/integer_gmp_imp.h>
 #  endif /* SWIG */
 #endif /* CVC4_GMP_IMP */
